@@ -20,8 +20,9 @@ from .exceptions import (
 from .roborock_future import RoborockFuture
 from .roborock_message import (
     RoborockMessage,
+    RoborockMessageProtocol,
 )
-from .util import get_next_int, get_running_loop_or_create_one
+from .util import get_next_int
 
 _LOGGER = logging.getLogger(__name__)
 KEEPALIVE = 60
@@ -31,10 +32,10 @@ class RoborockClient(ABC):
     """Roborock client base class."""
 
     _logger: logging.LoggerAdapter
+    queue_timeout: int
 
-    def __init__(self, device_info: DeviceData, queue_timeout: int = 4) -> None:
+    def __init__(self, device_info: DeviceData) -> None:
         """Initialize RoborockClient."""
-        self.event_loop = get_running_loop_or_create_one()
         self.device_info = device_info
         self._nonce = secrets.token_bytes(16)
         self._waiting_queue: dict[int, RoborockFuture] = {}
@@ -45,13 +46,6 @@ class RoborockClient(ABC):
             "misc_info": {"Nonce": base64.b64encode(self._nonce).decode("utf-8")}
         }
         self.is_available: bool = True
-        self.queue_timeout = queue_timeout
-
-    def __del__(self) -> None:
-        self.release()
-
-    def release(self) -> None:
-        self.sync_disconnect()
 
     async def async_release(self) -> None:
         await self.async_disconnect()
@@ -65,12 +59,12 @@ class RoborockClient(ABC):
         """Connect to the Roborock device."""
 
     @abstractmethod
-    def sync_disconnect(self) -> Any:
+    async def async_disconnect(self) -> Any:
         """Disconnect from the Roborock device."""
 
     @abstractmethod
-    async def async_disconnect(self) -> Any:
-        """Disconnect from the Roborock device."""
+    def is_connected(self) -> bool:
+        """Return True if the client is connected to the device."""
 
     @abstractmethod
     def on_message_received(self, messages: list[RoborockMessage]) -> None:
@@ -91,6 +85,7 @@ class RoborockClient(ABC):
 
     async def validate_connection(self) -> None:
         if not self.should_keepalive():
+            self._logger.info("Resetting Roborock connection due to keepalive timeout")
             await self.async_disconnect()
         await self.async_connect()
 
@@ -107,7 +102,9 @@ class RoborockClient(ABC):
 
     def _async_response(self, request_id: int, protocol_id: int = 0) -> Any:
         queue = RoborockFuture(protocol_id)
-        if request_id in self._waiting_queue:
+        if request_id in self._waiting_queue and not (
+            request_id == 2 and protocol_id == RoborockMessageProtocol.PING_REQUEST
+        ):
             new_id = get_next_int(10000, 32767)
             self._logger.warning(
                 "Attempting to create a future with an existing id %s (%s)... New id is %s. "
@@ -119,7 +116,3 @@ class RoborockClient(ABC):
             request_id = new_id
         self._waiting_queue[request_id] = queue
         return asyncio.ensure_future(self._wait_response(request_id, queue))
-
-    @abstractmethod
-    async def send_message(self, roborock_message: RoborockMessage):
-        """Send a message to the Roborock device."""
